package de.heise.mklemke.jprobe;

import java.awt.Container;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;

public class DBSelect implements ActionListener {
	JComboBox cbNummer = null;
	JTextField tfName = null;
	JTextField tfStreet = null;
	JTextField tfCity = null;
	private JFrame frame = null;

	public final static String SQL_CONNECTION = "jdbc:hsqldb:file:db/namen";
	public final static String SQL_SELECT_BY_ID = "SELECT id, firstname, lastname, street, city FROM CUSTOMER where id = ?";
	public final static String SQL_COUNT_ITEMS = "SELECT count(*) FROM CUSTOMER";
	public final static String SQL_SELECT_ALL = "SELECT id FROM CUSTOMER";

	public DBSelect() {

	} // DBSelect()

	public void buildFrontend() {
		frame = new JFrame();

		Container contentPane = frame.getContentPane();
		contentPane.setLayout(new GridBagLayout());
		GridBagConstraints gbc = new GridBagConstraints();
		gbc.anchor = GridBagConstraints.LINE_START;
		gbc.insets = new Insets(3, 3, 3, 3);

		JLabel label = new JLabel("Personalnummer: ");
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.gridy = 0;
		contentPane.add(label, gbc);

		Object[] listOfPersonals = getPersonalNumbers();

		cbNummer = new JComboBox(listOfPersonals);
		cbNummer.setEditable(false);
		gbc.gridx = 1;
		contentPane.add(cbNummer, gbc);

		JButton button = new JButton("Abfrage starten");
		gbc.gridx = 2;
		gbc.gridy = 0;
		contentPane.add(button, gbc);
		button.addActionListener(this);

		label = new JLabel("Name: ");
		gbc.gridx = 0;
		gbc.gridy = 1;
		contentPane.add(label, gbc);

		tfName = new JTextField(40);
		tfName.setEditable(false);
		gbc.gridx = 1;
		gbc.gridy = 1;
		gbc.gridwidth = 2;
		contentPane.add(tfName, gbc);

		label = new JLabel("Strae: ");
		gbc.gridx = 0;
		gbc.gridy = 2;
		gbc.gridwidth = 1;
		contentPane.add(label, gbc);

		tfStreet = new JTextField(40);
		tfStreet.setEditable(false);
		gbc.gridx = 1;
		gbc.gridy = 2;
		gbc.gridwidth = 2;
		contentPane.add(tfStreet, gbc);

		label = new JLabel("Ort: ");
		gbc.gridx = 0;
		gbc.gridy = 3;
		gbc.gridwidth = 1;
		contentPane.add(label, gbc);

		tfCity = new JTextField(20);
		tfCity.setEditable(false);
		gbc.gridx = 1;
		gbc.gridy = 3;
		gbc.gridwidth = 2;
		contentPane.add(tfCity, gbc);

		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.pack();
	} // public buildFrontend()

	private String[] getPersonalNumbers() {
		try {
			Class.forName("org.hsqldb.jdbcDriver");
		} catch (Exception e) {
			System.out.println("ERROR: failed to load HSQLDB JDBC driver.");
			e.printStackTrace();
			return null;
		}

		try {
			Connection c = DriverManager
					.getConnection(SQL_CONNECTION, "sa", "");

			PreparedStatement psCount = c.prepareStatement(SQL_COUNT_ITEMS);
			ResultSet rs = psCount.executeQuery();
			rs.next();
			int numberOfRows = rs.getInt(1);
			System.out.println("Number of Rows: " + numberOfRows);

			PreparedStatement ps = c.prepareStatement(SQL_SELECT_ALL);
			rs = ps.executeQuery();
			String s[] = new String[numberOfRows];
			for (int i = 0; i < numberOfRows; i++) {
				rs.next();
				s[i] = rs.getString("id");
			} // for (int i = 0; i < numberOfRows; i++)
			c.close();
			return s;
		} // try
		catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	} // private Object[] getPersonalNumbers()

	public void showFrontend() {
		frame.setVisible(true);
	} // public void showFrontend()

	public static void main(String[] args) {
		DBSelect dbSelect = new DBSelect();
		dbSelect.buildFrontend();
		dbSelect.showFrontend();
	} // public static void main(String[])

	public void actionPerformed(ActionEvent arg0) {
		String item = (String) cbNummer.getSelectedItem();
		Connection c = null;
		try {
			c = DriverManager.getConnection(SQL_CONNECTION, "sa", "");

			PreparedStatement psCount = c.prepareStatement(SQL_SELECT_BY_ID);
			psCount.setString(1, item);
			ResultSet rs = psCount.executeQuery();
			rs.next();
			String firstname = rs.getString("FirstName");
			String lastname = rs.getString("LastName");
			tfName.setText(firstname + " " + lastname);

			String street = rs.getString("Street");
			tfStreet.setText(street);

			String city = rs.getString("City");
			tfCity.setText(city);
			c.close();
		} // try
		catch (Exception e) {
			e.printStackTrace();
		} finally {
			try {
				c.close();
			} catch (Exception e) {
			}
		}

	} // public void actionPerformed(ActionEvent)

} // public class DBSelect
